@@ -429,11 +429,10 @@ def _select_to_dataframe_yield_selects_with_in_clauses(
     in_clauses_chunk_size: int | None = None,
     chunk_size_frac: float = CHUNK_SIZE_FRAC,
 ) -> Iterator[Select[Any]]:
-    max_length = len(sel.selected_columns)
     in_col, in_values = in_clauses
     if in_clauses_chunk_size is None:
         chunk_size = get_chunk_size(
-            engine, chunk_size_frac=chunk_size_frac, max_length=max_length
+            engine, sel.selected_columns, chunk_size_frac=chunk_size_frac
         )
     else:
         chunk_size = in_clauses_chunk_size
